import cnabssdk.clients
import cnabssdk.common.base_entry;
import cnabssdk.deals.entries;

def get_list(keywords="", beginDate="", endDate="", dealStatus="", year="", catalog="", orgName=""):
    url = "products/openapi/securities"
    params = {
        "keywords": keywords,
        "begin": beginDate,
        "end": endDate,
        "status": dealStatus,
        "year": year,
        "catalog": catalog,
        "orgName": orgName
    }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_detail(securityCodeOrId):
    url = "products/openapi/securities/" + securityCodeOrId
    return cnabssdk.clients.cnabsclient().get(url, {})


import requests
import json
import cnabssdk
import cnabssdk.configs

class cnabsclient:
    def __init__(self, accessToken = "", apiHost = 'https://api.cn-abs.com'):
        self.apiHost = apiHost
        self.accessToken = accessToken
        if(self.accessToken == ""):
            self.accessToken = cnabssdk.configs.TOKEN
        if(self.apiHost == ""):
            self.apiHost = cnabssdk.configs.API_HOST

        print("init cnabs client: " + self.apiHost)
        self.head = {
            'user-agent': 'cnabs python client v1.0',
            'Authorization': 'Bearer ' + self.accessToken
        }

    def __checkResponse(self, jsonObj):
        obj = obj_dic(jsonObj)
        code = obj.code
        message = obj.message
        data = obj.data
        if code != 200:
            raise Exception("服务错误: " + message)
        return data
        
        
    def __get_urls(self, resource):
        if resource.startswith('http'):
            return resource
        else:
            return self.apiHost + '/' + resource
        return ""

    def get(self, resource, parameters = {}):
        url = self.__get_urls(resource)
        response = requests.get(url, parameters, headers= self.head)
        if response.status_code != 200:
            raise Exception("服务错误: status_code: " + response.status_code)
        jsonObj = json.loads(response.text)
        return self.__checkResponse(jsonObj)
        
    
def obj_dic(d):
    top = type('new', (object,), d)
    seqs = tuple, list, set, frozenset
    for i, j in d.items():
        if isinstance(j, dict):
            setattr(top, i, obj_dic(j))
        elif isinstance(j, seqs):
            setattr(top, i, 
                type(j)(obj_dic(sj) if isinstance(sj, dict) else sj for sj in j))
        else:
            setattr(top, i, j)
    return top


import cnabssdk.clients
import cnabssdk.common.base_entry;
import cnabssdk.deals.entries;

def get_list(keyworkds = "", status = "", year = "", catalog = "", orgname = ""):
    url = "products/openapi/deals"
    params = {
        "keywords": keyworkds,
        "status": status,
        "year": year,
        "catalog": catalog,
        "orgname": orgname
        }
    data = cnabssdk.clients.cnabsclient().get(url, params)
    results = []
    for d in data:
        dlist = cnabssdk.deals.entries.deal_list_entry()
        dlist.__dict__.update(d.__dict__)
        results.append(dlist)
    
    return results

def get_info(dealIdOrName):
    url = "products/openapi/deals/" + dealIdOrName
    data = cnabssdk.clients.cnabsclient().get(url, {})
    deal = cnabssdk.deals.entries.deal_info_entry()
    if(data != None):
        deal.__dict__.update(data.__dict__)
    return (deal)




import cnabssdk.common.base_entry
import cnabssdk.common.utility

class deal_list_entry(cnabssdk.common.base_entry.baseEntry):
    def __init__(self, id = "", name = "", code = "", status = "", shortname = ""):
        super().__init__(id, code, name)
        self.status = status
        self.short_name = shortname

    def loadFromJson(self, jsonObj):
        super().loadFromJson(jsonObj)
        self.status = jsonObj["status"]
        self.short_name = jsonObj["short_name"]

class deal_info_entry(deal_list_entry):
    def __init__(self):
        super().__init__()
        self.total_offering = 0
        self.cut_off_date = ''
        


__author__ = "Bo Pan"

from setuptools import setup, find_packages

with open("./cnabssdk/PackHelper.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()


setup(name='cnabs_sdk',
      version='0.0.3', 
      description='CNABS OPENAPI SDK',
      author='Bo Pan', 
      author_email='bo.pan@cn-abs.com',
      url='https://github.com/cnabs',
      packages= ["cnabssdk", "cnabssdk.common", "cnabssdk.deals", "cnabssdk.securities"], 
      long_description=long_description,
      long_description_content_type="text/markdown", 
      license="GPLv3", 
      classifiers=[
          "Programming Language :: Python :: 3", 
          "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
          "Operating System :: OS Independent"],
      python_requires='>=3.3',
      install_requires=[
          "requests>=2.2.0",
          ]
      )


def obj_dic(d):
    top = type('new', (object,), d)
    seqs = tuple, list, set, frozenset
    for i, j in d.items():
    	if isinstance(j, dict):
    	    setattr(top, i, obj_dic(j))
    	elif isinstance(j, seqs):
    	    setattr(top, i, 
    		    type(j)(obj_dic(sj) if isinstance(sj, dict) else sj for sj in j))
    	else:
    	    setattr(top, i, j)

class obj(object):
    def __init__(self, d):
        for a, b in d.items():
            if isinstance(b, (list, tuple)):
               setattr(self, a, [obj(x) if isinstance(x, dict) else x for x in b])
            else:
               setattr(self, a, obj(b) if isinstance(b, dict) else b)


class baseEntry(object):
    def __init__(self,id= '' ,code = '', name = ''):
        self.id = id
        self.code = code
        self.name = name

    def loadFromJson(self, obj):
        self.id = obj['id']
        self.code = obj['code']
        self.name = obj['name']